@@ -214,3 +214,7 @@
 #define MSG_ALIASES_LIST "µıã"
 #define MSG_PERUSER_MAX "޷ͬһʹ߳ %lu "
 #define MSG_IPV6_OK "ⲿҲӭIPv6"
+#define MSG_TLS_INFO "SSL/TLS:  %s with %s, %d λԪ"
+#define MSG_TLS_WEAK "SSL/TLS: 벻"
+#define MSG_TLS_NEEDED "Ǹŷʽߡ\n" \
+    "ʹSSL/TLSİȫߡ"
